==> cloudfeaster-0.9.6.tar.gz: cloudfeaster-0.9.6/README.md <==
# cloudfeaster
![Maintained](https://img.shields.io/maintenance/yes/2017.svg?style=flat)
![license](https://img.shields.io/pypi/l/cloudfeaster.svg?style=flat)
![PythonVersions](https://img.shields.io/pypi/pyversions/cloudfeaster.svg?style=flat)
![status](https://img.shields.io/pypi/status/cloudfeaster.svg?style=flat)
[![PyPI](https://img.shields.io/pypi/v/cloudfeaster.svg?style=flat)](https://pypi.python.org/pypi/cloudfeaster)
[![Requirements](https://requires.io/github/simonsdave/cloudfeaster/requirements.svg?branch=release-0.9.6)](https://requires.io/github/simonsdave/cloudfeaster/requirements/?branch=release-0.9.6)
[![Build Status](https://travis-ci.org/simonsdave/cloudfeaster.svg?branch=release-0.9.6)](https://travis-ci.org/simonsdave/cloudfeaster)
[![Coverage Status](https://coveralls.io/repos/simonsdave/cloudfeaster/badge.svg?style=flat)](https://coveralls.io/r/simonsdave/cloudfeaster)
[![docker-simonsdave/cloudfeaster](https://img.shields.io/badge/docker-simonsdave%2Fcloudfeaster-blue.svg?style=flat)](https://hub.docker.com/r/simonsdave/cloudfeaster/)

Cloudfeaster is a screen scraping infrastructure that leverages
modern software engineering tools, services and trends to create:

* [a spider authoring and maintenance environment](https://github.com/simonsdave/cloudfeaster)
* [an IaaS enabled service infrastructure for discovering
and running spiders via a RESTful API](https://github.com/simonsdave/ecs)

[This](https://github.com/simonsdave/dev-env/tree/release-0.9.6/docs/story.md) is the story behind Cloudfeaster.

## What Next

* see [these](https://github.com/simonsdave/dev-env/tree/release-0.9.6/docs/contributing.md) instructions
describe how to setup your development environment and
start contributing to Cloudfeaster
* [this](https://github.com/simonsdave/dev-env/tree/release-0.9.6/docs/spider_authors.md) describes
how to author spiders using Cloudfeaster

==> cloudfeaster-0.9.7.tar.gz: cloudfeaster-0.9.7/README.md <==
# cloudfeaster
![Maintained](https://img.shields.io/maintenance/yes/2017.svg?style=flat)
![license](https://img.shields.io/pypi/l/cloudfeaster.svg?style=flat)
![PythonVersions](https://img.shields.io/pypi/pyversions/cloudfeaster.svg?style=flat)
![status](https://img.shields.io/pypi/status/cloudfeaster.svg?style=flat)
[![PyPI](https://img.shields.io/pypi/v/cloudfeaster.svg?style=flat)](https://pypi.python.org/pypi/cloudfeaster)
[![Requirements](https://requires.io/github/simonsdave/cloudfeaster/requirements.svg?branch=release-0.9.7)](https://requires.io/github/simonsdave/cloudfeaster/requirements/?branch=release-0.9.7)
[![Build Status](https://travis-ci.org/simonsdave/cloudfeaster.svg?branch=release-0.9.7)](https://travis-ci.org/simonsdave/cloudfeaster)
[![Coverage Status](https://coveralls.io/repos/simonsdave/cloudfeaster/badge.svg?style=flat)](https://coveralls.io/r/simonsdave/cloudfeaster)
[![docker-simonsdave/cloudfeaster](https://img.shields.io/badge/docker-simonsdave%2Fcloudfeaster-blue.svg?style=flat)](https://hub.docker.com/r/simonsdave/cloudfeaster/)

Cloudfeaster is a screen scraping infrastructure that leverages
modern software engineering tools, services and trends to create:

* [a spider authoring and maintenance environment](https://github.com/simonsdave/cloudfeaster)
* [an IaaS enabled service infrastructure for discovering
and running spiders via a RESTful API](https://github.com/simonsdave/ecs)

[This](https://github.com/simonsdave/cloudfeaster/tree/release-0.9.7/docs/story.md) is the story behind Cloudfeaster.

## What Next

* see [these](https://github.com/simonsdave/cloudfeaster/tree/release-0.9.7/docs/contributing.md) instructions
describe how to setup your development environment and
start contributing to Cloudfeaster
* [this](https://github.com/simonsdave/cloudfeaster/tree/release-0.9.7/docs/spider_authors.md) describes
how to author spiders using Cloudfeaster
